# pyRealEstate

pyRealEstate is a package designed for data scientists working in the real estate industry.  This Library aims to provide tools to help in the preprocessing of data, feature engineering and evaluation 
of AVM's (Automated valuation models). Some of metrics provided in this library are the COD ( coeficient of Disspersion), PRD ( Price Relted Differential) and weighted mean for example. pyRealEstate is still currently under development 
but is aimed at providing functions to assist in the development and evaluation of AVM's sp please continually check for updates . 

## Instilation

Simply run:
```
pip3 install pyRealEstate
```
